<?php namespace EscapeWork\Manager\Press\Controllers;

use EscapeWork\Manager\Press\Repositories\PressDownloadRepository;
use EscapeWork\Manager\Press\Repositories\PressRepository;
use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Press\Models\Press;
use Redirect;
use Response;
use Config;
use Input;
use View;
use Msg;

class PressController extends ManagerController
{
    public function __construct(PressRepository $press, PressDownloadRepository $pressDownload)
    {
        $this->press         = $press;
        $this->pressDownload = $pressDownload;

        # filters
        $this->validatePermissions('presses');

        View::share('page', 'presses');
    }

    public function index()
    {
        $view          = View::make(Config::get('manager-press::views.press.index'));
        $view->presses = $this->press->getPaginated();

        return $view;
    }

    public function create()
    {
        $this->press->fill(Input::old());

        $view        = View::make(Config::get('manager-press::views.press.form'));
        $view->press = $this->press;
        $view->edit  = false;

        return $view;
    }

    public function store()
    {
        $this->press->fill(Input::all());

        if (! $this->press->validate()) {
            return Redirect::route('manager.press.create')
                        ->withInput()
                        ->withErrors($this->press->messages());
        }

        $this->press->save();
        $this->pressDownload->press_id = $this->press->id;
        $this->pressDownload->insertFromArray(Input::file('files'));

        return Redirect::route('manager.press.index')->with('message', 'A matéria <strong>' . $this->press->title . '</strong> foi inserida com sucesso!');
    }

    public function edit($id)
    {
        $this->press = $this->press->findOrFail($id);

        $view        = View::make(Config::get('manager-press::views.press.form'));
        $view->press = $this->press;
        $view->edit  = true;

        return $view;
    }

    public function update($id)
    {
        $this->press = $this->press->findOrFail($id);
        $this->press->fill(Input::all());

        if (! $this->press->validate()) {
            return Redirect::route('manager.press.edit', array($this->press->id))
                    ->withInput()
                    ->withErrors($this->press->messages());
        }

        $this->press->save();

        if (Input::file('files')) {
            $this->pressDownload->press_id = $this->press->id;
            $this->pressDownload->insertFromArray();
        }

        return Redirect::route('manager.press.index')
                ->with('message', 'A matéria <strong>'.$this->press->title.'</strong> foi editada com sucesso!');
    }

    public function destroy($id)
    {
        $this->press                   = $this->press->findOrFail($id);
        $this->pressDownload->press_id = $this->press->id;
        $this->pressDownload->deleteFromPress();
        $this->press->delete();

        return Redirect::route('manager.press.index')
                ->with('message', 'A mídia <strong>'.$this->press->title.'</strong> foi excluída com sucesso!');
    }

    public function destroyFile($download_id)
    {
        $this->pressDownload = $this->pressDownload->findOrFailBy('id', $download_id);

        $pressId             = $this->pressDownload->press_id;
        $this->pressDownload->delete();

        return Redirect::route('manager.press.edit',$pressId)
                    ->withInput()
                    ->with('message', 'Arquivo excluído com sucesso!');
    }

    public function updateActive($id)
    {
        $this->press         = $this->press->findOrFail($id);
        $this->press->active = Input::get('active');
        $this->press->save();

        return Response::json(array(
            'message' => 'A imprensa foi atualizada com sucesso'
        ));
    }
}
