<?php namespace EscapeWork\Manager\Press\Repositories;

use EscapeWork\LaravelHelpers\BaseRepository;
use EscapeWork\Manager\Press\Models\PressDownload;
use Symfony\Component\HttpFoundation\File\UploadedFile;
use Str;

class PressDownloadRepository extends BaseRepository
{

    /**
     * Diretório
     */
    protected $dir = 'files/downloads';

    public function __construct(PressDownload $pressDownload)
    {
        $this->model = $pressDownload;
    }

    /**
     * Inserindo os arquivos
     */
    public function insertFromArray($files)
    {
        foreach ($files as $file) {
            if ($file instanceof UploadedFile) {
                $this->insert($file);
            }
        }
    }

    /**
     * Inserindo um arquivo
     */
    public function insert(UploadedFile $file)
    {
        $filename = $this->formatFileName($file);
        $file->move($this->getDir(), $filename);

        $pressDownload = new PressDownload();
        $pressDownload->press_id = $this->model->press_id;
        $pressDownload->file = $filename;
        $pressDownload->save();
    }

    protected function formatFileName(UploadedFile $file)
    {
        $string  = explode('.', $file->getClientOriginalName());
        unset($string[count($string) - 1]);

        $slug = Str::slug(implode('.', $string));
        return $slug . '.' . $file->guessExtension();
    }

    protected function getDir()
    {
        return public_path() . '/' . $this->dir;
    }

    public function delete()
    {
        $this->deleteFile($this->model->file);

        return $this->model->delete();
    }

    protected function deleteFile($filename)
    {
        $file = $this->getDir() . '/' . $filename;

        if (is_file($file)) {
            unlink($file);
        }
    }

    public function deleteFromPress()
    {
        $downloads = $this->model->where('press_id', '=', $this->model->press_id)->get();

        foreach ($downloads as $download) {
            $this->deleteFile($download->file);
            $download->delete();
        }
    }
}
